(*:Copyright: Copyright 1988-2003 Wolfram Research, Inc. *)

(*:Mathematica Version: 3.0 *)

(*:Package Version: 1.0 *)

(*:Name: Algebra`Zorn` *)

(*:Title: Zorn matrices algebra *) 

(*:Author: Cndido Martn Gonzlez *)

(*:Keywords: spit octonions, Zorn matrices *)

(* :Sources: Russian's book: Rings that are nearly associative*)

(*:Summary:
Package for computations with split octonions*)

BeginPackage["Algebra`Zorn`"]

p::usage = "Gives the product p[x,y] of the octonions x and y."

rec::usage= "Writes an octonion as a formal linear combinations of elements in the standard 
basis."

B::usage="Standar basis of split Octonions."

cero::usage="cero Zorn matrix."

uno::usage="unit Zorn matrix."

Cayley::usage="Conjugate of octonion."

trace::usage="trace of octonion."

norm::usage="norm of octonion."

avec::usage="octonion to vector."

aoct::usage="vector to octonion."

LinearMap::usage="Linear map with given matrix"

e::usage="Idempotents (needs subscript = 1,2)."

u::usage="Elements in the (1,0) Peirce space (relative to e_1) of Zorn's algebra 
(needs subscript = 1,3)."

v::usage="Elements in the (0,1) Peirce space (relative to e_1) of Zorn's algebra 
(needs subscript = 1,3)."

recT::usage="TeX Form of rec."

Begin["Algebra`Zorn`Private`"]

(*:Unprotect[SemialgebraicComponents]*)

p[x_,y_]:={{x[[1,1]]y[[1,1]]+x[[1,2]].y[[2,1]],x[[1,1]]y[[1,2]]+y[[2,2]]x[[1,2]]-Cross[x[[2,1]],
y[[2,1]]]},{y[[1,1]]x[[2,1]]+x[[2,2]]y[[2,1]]+Cross[x[[1,2]],y[[1,2]]],
x[[2,1]].y[[1,2]]+x[[2,2]]y[[2,2]]}};

rec[x_]:=Sum[x[[i,i]] Subscript["e",i],{i,2}]+Sum[x[[1,2]][[i]] Subscript["u",i],{i,3}]+
Sum[x[[2,1]][[i]] Subscript["v",i],{i,3}]

recT[x_]:=TeXForm[rec[x]]

B={{{1,{0,0,0}},{{0,0,0},0}},
{{0,{0,0,0}},{{0,0,0},1}},
{{0,{1,0,0}},{{0,0,0},0}},
{{0,{0,1,0}},{{0,0,0},0}},
{{0,{0,0,1}},{{0,0,0},0}},
{{0,{0,0,0}},{{1,0,0},0}},
{{0,{0,0,0}},{{0,1,0},0}},
{{0,{0,0,0}},{{0,0,1},0}}}

Do[Subscript[e,i]=B[[i]],{i,2}]

Do[Subscript[u,i]=B[[2+i]],{i,3}]

Do[Subscript[v,i]=B[[5+i]],{i,3}]

cero={{0,{0,0,0}},{{0,0,0},0}}

uno={{1,{0,0,0}},{{0,0,0},1}}

Cayley[x_]:={{x[[2,2]],-x[[1,2]]},{-x[[2,1]],x[[1,1]]}}

trace[x_]:=Expand[x+Cayley[x]][[1,1]]

norm[x_]:=Expand[p[x,Cayley[x]]][[1,1]]

avec[x_]:={x[[1,1]],x[[2,2]],x[[1,2]][[1]],x[[1,2]][[2]],x[[1,2]][[3]],x[[2,1]][[1]],
x[[2,1]][[2]],x[[2,1]][[3]]}

aoct[x_]:={{x[[1]],{x[[3]],x[[4]],x[[5]]}},{{x[[6]],x[[7]],x[[8]]},x[[2]]}}

LinearMap[M_,x_]:=aoct[M.avec[x]]//Expand


End[]  (* Algebra`Zorn`Private` *)

(*Protect[SemialgebraicComponents]*)

EndPackage[]  (* Algebra`Zorn` *)

            
